@@ -21,7 +21,7 @@ Usage (cli):
 
     $ ls | jc --ls
 
-    or
+or
 
     $ jc ls
 
@@ -118,7 +118,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.11'
+    version = '1.12'
     description = '`ls` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -141,8 +141,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'links', 'size'}
+
     for entry in proc_data:
-        int_list = ['links', 'size']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
