@@ -1,20 +1,20 @@
 """jc - JSON Convert `ping` command output streaming parser
 
 > This streaming parser outputs JSON Lines (cli) or returns an Iterable of
-  Dictionaries (module)
+> Dictionaries (module)
 
 Supports `ping` and `ping6` output.
 
 Usage (cli):
 
-    $ ping | jc --ping-s
+    $ ping 1.2.3.4 | jc --ping-s
 
 > Note: When piping `jc` converted `ping` output to other processes it may
-  appear the output is hanging due to the OS pipe buffers. This is because
-  `ping` output is too small to quickly fill up the buffer. Use the `-u`
-  option to unbuffer the `jc` output if you would like immediate output.
-  See the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
-  for more information.
+> appear the output is hanging due to the OS pipe buffers. This is because
+> `ping` output is too small to quickly fill up the buffer. Use the `-u`
+> option to unbuffer the `jc` output if you would like immediate output.
+> See the [readme](https://github.com/kellyjonbrazil/jc/tree/master#unbuffering-output)
+> for more information.
 
 Usage (module):
 
@@ -85,7 +85,7 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.1'
     description = '`ping` and `ping6` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -108,14 +108,15 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = [
+    int_list = {
         'sent_bytes', 'packets_transmitted', 'packets_received', 'response_bytes', 'icmp_seq',
         'ttl', 'duplicates', 'vr', 'hl', 'tos', 'len', 'id', 'flg', 'off', 'pro', 'cks'
-    ]
-    float_list = [
+    }
+
+    float_list = {
         'packet_loss_percent', 'round_trip_ms_min', 'round_trip_ms_avg', 'round_trip_ms_max',
         'round_trip_ms_stddev', 'timestamp', 'time_ms'
-    ]
+    }
 
     for key in proc_data:
         if key in int_list:
